Documentation
¶
Index ¶
- type Dump
- type DumpClient
- func (dc *DumpClient) GetByDate(from, to time.Time) ([]Dump, error)
- func (dc *DumpClient) GetDumpContent(id string) (string, error)
- func (dc *DumpClient) Search(keyword string) ([]Dump, error)
- func (dc *DumpClient) SearchByDomain(domain string) ([]Dump, error)
- func (dc *DumpClient) SearchByEmail(email string) ([]Dump, error)
- func (dc *DumpClient) SetHTTPClient(client *http.Client) *DumpClient
- func (dc *DumpClient) SetUserAgent(useragent string) *DumpClient
- type Dumplings
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DumpClient ¶
type DumpClient struct {
// contains filtered or unexported fields
}
DumpClient facilitates interaction with the psbdmp service
func NewDumpClient ¶
func NewDumpClient() *DumpClient
NewDumpClient returns a dumpclient instance initialized with sane defaults
func (*DumpClient) GetByDate ¶
func (dc *DumpClient) GetByDate(from, to time.Time) ([]Dump, error)
GetByDate returns a list of the dumps that we're posted between the given dates
func (*DumpClient) GetDumpContent ¶
func (dc *DumpClient) GetDumpContent(id string) (string, error)
GetDumpContent returns the full dump as a string
func (*DumpClient) Search ¶
func (dc *DumpClient) Search(keyword string) ([]Dump, error)
Search performs a generalized search across the dumps for the provided key word
func (*DumpClient) SearchByDomain ¶
func (dc *DumpClient) SearchByDomain(domain string) ([]Dump, error)
SearchByDomain searches for dumps containing the provided domain
func (*DumpClient) SearchByEmail ¶
func (dc *DumpClient) SearchByEmail(email string) ([]Dump, error)
SearchByEmail searches for dumps containing the provided email
func (*DumpClient) SetHTTPClient ¶
func (dc *DumpClient) SetHTTPClient(client *http.Client) *DumpClient
SetHTTPClient allows a custom HTTP Client to be used
func (*DumpClient) SetUserAgent ¶
func (dc *DumpClient) SetUserAgent(useragent string) *DumpClient
SetUserAgent allows a custom User-Agent to be applied
Click to show internal directories.
Click to hide internal directories.